# BUSY Bar Tools

This is a set of command-line tools for managing the BUSY Bar.

## Installation

You can install the package using pip:

```
pip install busybar-tools
```

## Usage

To use the tools, simply run the `busybar` command followed by the desired subcommand:

```
busybar <subcommand> [options]
```

## Examples

Install firmware from CI. Default branch is `dev`

```
busybar update [branch or url]
```

